pub trait Column:
Sealed
+ 'static
+ Send
+ Sync
+ Debug {
type Database: Database;
// Required methods
fn ordinal(&self) -> usize;
fn name(&self) -> &str;
fn type_info(&self) -> &<Self::Database as Database>::TypeInfo;
}Required Associated Types
Required Methods
Sourcefn ordinal(&self) -> usize
fn ordinal(&self) -> usize
Gets the column ordinal.
This can be used to unambiguously refer to this column within a row in case more than one column have the same name
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl Column for AnyColumn
Available on crate feature any and (crate features mssql or mysql or odbc or postgres or sqlite) only.
impl Column for AnyColumn
Available on crate feature
any and (crate features mssql or mysql or odbc or postgres or sqlite) only.Sourceimpl Column for MssqlColumn
Available on crate feature mssql only.
impl Column for MssqlColumn
Available on crate feature
mssql only.Sourceimpl Column for MySqlColumn
Available on crate feature mysql only.
impl Column for MySqlColumn
Available on crate feature
mysql only.