pub trait HasStatement<'q> {
type Database: Database;
type Statement: Statement<'q, Database = Self::Database>;
}Expand description
Associate Database with a Statement of a generic lifetime.
The upcoming Rust feature, Generic Associated Types, should obviate the need for this trait.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl<'q> HasStatement<'q> for Any
Available on crate feature any and (crate features mssql or mysql or odbc or postgres or sqlite) only.
impl<'q> HasStatement<'q> for Any
Available on crate feature
any and (crate features mssql or mysql or odbc or postgres or sqlite) only.Sourceimpl<'q> HasStatement<'q> for Mssql
Available on crate feature mssql only.
impl<'q> HasStatement<'q> for Mssql
Available on crate feature
mssql only.Sourceimpl<'q> HasStatement<'q> for MySql
Available on crate feature mysql only.
impl<'q> HasStatement<'q> for MySql
Available on crate feature
mysql only.Sourceimpl<'q> HasStatement<'q> for Odbc
Available on crate feature odbc only.
impl<'q> HasStatement<'q> for Odbc
Available on crate feature
odbc only.Sourceimpl<'q> HasStatement<'q> for Postgres
Available on crate feature postgres only.
impl<'q> HasStatement<'q> for Postgres
Available on crate feature
postgres only.