pub struct SqliteFunctionCtx { /* private fields */ }Available on crate feature
sqlite only.Implementations
Sourceimpl SqliteFunctionCtx
impl SqliteFunctionCtx
Sourcepub fn get_arg<'q, T: Decode<'q, Sqlite>>(&'q self, index: usize) -> T
pub fn get_arg<'q, T: Decode<'q, Sqlite>>(&'q self, index: usize) -> T
Returns the argument at the given index, or panics if the argument number is out of bounds or the argument cannot be decoded as the requested type.
Sourcepub fn try_get_arg<'q, T: Decode<'q, Sqlite>>(
&'q self,
index: usize,
) -> Result<T, BoxDynError>
pub fn try_get_arg<'q, T: Decode<'q, Sqlite>>( &'q self, index: usize, ) -> Result<T, BoxDynError>
Returns the argument at the given index, or None if the argument number is out of bounds or
the argument cannot be decoded as the requested type.
pub fn set_result<'q, R: Encode<'q, Sqlite>>(&self, result: R)
pub fn set_error(&self, error_str: &str)