pub trait MigrationSource<'s>: Debug {
// Required method
fn resolve(self) -> BoxFuture<'s, Result<Vec<Migration>, BoxDynError>>;
}Available on crate feature
migrate only.Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl MigrationSource<'static> for PathBuf
impl MigrationSource<'static> for PathBuf
Sourceimpl<'s> MigrationSource<'s> for &'s Path
Implementation of the MigrationSource for std::path::Path.
impl<'s> MigrationSource<'s> for &'s Path
Implementation of the MigrationSource for std::path::Path.
The path has to point to a directory, which contains the migration SQL scripts. All these
scripts must be stored in files with names using the format <VERSION>_<DESCRIPTION>.sql,
where <VERSION> is a string that can be parsed into i64 and its value is greater than zero,
and <DESCRIPTION> is a string.